@@ -2,8 +2,8 @@
 {
    library.dynam("BPHO",pkg,lib)
    cat("Bayesian Prediction with High-order Models(BPHO) loaded\n", 
-       "COPY RIGHT (c) Longhai Li, http://math.usask.ca/~longhai\n",
-	"Type ?begin.BPHO for help\n",sep="")
+       "COPYRIGHT 2007-2008 (c) Longhai Li (http://math.usask.ca/~longhai)\n",
+	"Type ?begin.BPHO for help to this package\n",sep="")
 
 }
 
